%define major 0
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:           gfan
Version:        0.6.2
Release:        %mkrel 6
Summary:        Software for Computing Gröbner Fans and Tropical Varieties
Group:          Development/C
License:        GPLv2+
URL:            https://home.math.au.dk/jensen/software/gfan/gfan.html
Source0:        https://home.math.au.dk/jensen/software/%{name}/%{name}%{version}.tar.gz
# Sent upstream 2011 Apr 27.  Fix warnings that could indicate runtime
# problems.
Patch0:         gfan-warning.patch
# Treat plain "gfan" call as "gfan_bases" call (as done in previous versions)
# instead of warning that "gfan_bases" should be called and exiting
Patch1:         gfan-permissive.patch
# Build a shared library
Patch2:         gfan-shared.patch

BuildRequires:  cddlib-devel
BuildRequires:  gcc-c++
# BuildRequires:  ghostscript-tools-dvipdf
BuildRequires:  dvipdf
BuildRequires:  gmp-devel
BuildRequires:  texlive-texmf
BuildRequires:  topcom
BuildRequires:  locales-en

Suggests:       topcom

%description
The software computes all marked reduced Gröbner bases of an ideal.
Their union is a universal Gröbner basis. Gfan contains algorithms for
computing this complex for general ideals and specialized algorithms
for tropical curves, tropical hypersurfaces and tropical varieties of
prime ideals. In addition to the above core functions the package
contains many tools which are useful in the study of Gröbner bases,
initial ideals and tropical geometry. Among these are an interactive
traversal program for Gröbner fans and programs for graphical renderings.

%package        doc
Summary:        Gfan examples and documentation files
Requires:       %{name} = %{version}-%{release}

%description    doc
Gfan examples and documentation files.

%package -n %{libname}
Summary:        Polyhedral computations related to polynomial rings

%description -n %{libname}
Gfanlib has two major features:
1) high-level exact polyhedral cone and polyhedral fan classes;
2) fast exact mixed volume computation for lattice polytopes with overflow
   checking.

In particular, gfanlib is missing the Gröbner basis part of gfan.

%package -n %{develname}
Summary:        Development files for libgfan
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Requires:       gmp-devel

%description -n %{develname}
The libgfan-devel package contains libraries and header files for
developing applications that use libgfan.

%prep
%setup -q -n %{name}%{version}
%patch -P 0
%patch -P 1
%patch -P 2

# Point to where the TOPCOM binaries will be installed
sed -i.orig "s|^\(#define MINKOWSKIPROGRAM \).*|\1\"%{_bindir}/essai\"|" \
  src/minkowskisum.cpp
touch -r src/minkowskisum.cpp.orig src/minkowskisum.cpp
rm -f src/minkowskisum.cpp.orig

# No need to install a simple upstream Makefile to rsync homepage
# directory to upstream page.
rm -f homepage/Makefile

%build
%make_build CC=gcc CXX=g++ \
  OPTFLAGS="%{optflags} -DGMPRATIONAL -I%{_includedir}/cddlib" \
  PREFIX=%{_prefix} \
  SOPLEX_LINKOPTIONS="%{ldflags}"

# Build the manual
pushd doc
latex manual.tex
bibtex manual
latex manual.tex
latex manual.tex
dvipdf manual.dvi manual.pdf
popd

%install
# Install the library
mkdir -p %{buildroot}%{_libdir}
cp -p src/libgfan.so.0.0.0 %{buildroot}%{_libdir}
ln -s libgfan.so.0.0.0 %{buildroot}%{_libdir}/libgfan.so.0
ln -s libgfan.so.0 %{buildroot}%{_libdir}/libgfan.so

# Install the headers
mkdir -p %{buildroot}%{_includedir}/gfanlib
cp -p src/gfanlib*.h %{buildroot}%{_includedir}/gfanlib

# Fix the headers
for fil in %{buildroot}%{_includedir}/gfanlib/*.h; do
  sed -i.orig 's,#include "\(.*\)",#include <\1>,' $fil
  touch -r $fil.orig $fil
  rm $fil.orig
done

# Install the binaries
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
make install PREFIX=%{buildroot}%{_prefix}
pushd %{buildroot}%{_bindir}
    ./%{name} installlinks
popd


%check
# Some tests depend on US English collation order
export LC_ALL=en_US.UTF-8

# The xfig test output varies slightly by architecture, and is non-critical,
# so we skip that test.
rm -fr testsuite/0009RenderStairCase
export LD_LIBRARY_PATH=%{buildroot}%{_libdir}
./gfan _test


%files
%doc README doc/manual.pdf
%license COPYING LICENSE
%{_bindir}/*

%files          doc
%doc examples
%doc homepage

%files -n %{libname}
%doc gfanlib/README.txt
%{_libdir}/*.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/gfanlib/
%{_libdir}/*.so




%changelog
* Sat Dec 21 2024 pterjan <pterjan> 0.6.2-6.mga10
+ Revision: 2127395
- Rebuild for patchN deprecation

* Sat Mar 19 2022 umeabot <umeabot> 0.6.2-5.mga9
+ Revision: 1799576
- Mageia 9 Mass Rebuild

* Sat Aug 14 2021 wally <wally> 0.6.2-4.mga9
+ Revision: 1741334
- fix topcom BR
- clean .spec a bit

* Sat Feb 15 2020 umeabot <umeabot> 0.6.2-3.mga8
+ Revision: 1523579
- Mageia 8 Mass Rebuild

* Sun Mar 10 2019 shlomif <shlomif> 0.6.2-2.mga7
+ Revision: 1373617
- add provides

* Sat Mar 09 2019 shlomif <shlomif> 0.6.2-1.mga7
+ Revision: 1373391
- mageiaify
- import from fedora

